@@ -141,7 +141,7 @@ public Q_SLOTS:
      * \param resources The resources to be merged. Blank nodes will be converted into new
      * URIs (unless the corresponding resource already exists).
      * \param identificationMode This method can try hard to avoid duplicate resources by looking
-     * for already existing duplicates based on nrl:IdentifyingProperty. By default it only looks
+     * for already existing duplicates based on nrl:DefiningProperty. By default it only looks
      * for duplicates of resources that do not have a resource URI (SimpleResource::uri()) defined.
      * This behaviour can be changed with this parameter.
      * \param flags Additional flags to change the behaviour of the method.
@@ -152,7 +152,7 @@ public Q_SLOTS:
      * such as int, string, or url are supported.
      * \param app The calling application
      */
-    void storeResources(const SimpleResourceGraph& resources,
+    QHash<QUrl,QUrl> storeResources(const SimpleResourceGraph& resources,
                         const QString& app,
                         Nepomuk::StoreIdentificationMode identificationMode = Nepomuk::IdentifyNew,
                         Nepomuk::StoreResourcesFlags flags = Nepomuk::NoStoreResourcesFlags,
@@ -172,7 +172,7 @@ public Q_SLOTS:
      * \param userSerialization If \p serialization is Soprano::SerializationUser this value is used. See Soprano::Parser
      * for details.
      * \param identificationMode This method can try hard to avoid duplicate resources by looking
-     * for already existing duplicates based on nrl:IdentifyingProperty. By default it only looks
+     * for already existing duplicates based on nrl:DefiningProperty. By default it only looks
      * for duplicates of resources that do not have a resource URI (SimpleResource::uri()) defined.
      * This behaviour can be changed with this parameter.
      * \param flags Additional flags to change the behaviour of the method.
@@ -192,11 +192,15 @@ public Q_SLOTS:
 
     /**
      * Describe a set of resources, i.e. retrieve all their properties.
-     * \param resources The resource URIs of the resources to describe.
-     * \param includeSubResources If \p true sub resources will be included.
+     * \param resources The resource URIs of the resources to describe. Non-existing resources are ignored.
+     * \param flags Optional flags to modify the data which is returned.
+     * \param targetParties This optional list can be used to specify the parties (nao:Party) which should
+     * receive the returned data. This will result in a filtering of the result according to configured
+     * permissions. Only data which is set as being public or readable by the specified parties is returned.
      */
     SimpleResourceGraph describeResources(const QList<QUrl>& resources,
-                                          bool includeSubResources) const;
+                                          DescribeResourcesFlags flags = NoDescribeResourcesFlags,
+                                          const QList<QUrl>& targetParties = QList<QUrl>() ) const;
     //@}
 
 private:
@@ -274,9 +278,9 @@ private:
      * Resolves local file URLs through nie:url.
      * \return a Hash mapping \p urls to their actual resource URIs or an empty QUrl if the resource does not exist.
      *
-     * This method does check if the local file exists and may set an error.
+     * \param statLocalFiles If \p true this method does check if the local file exists and may set an error if not.
      */
-    QHash<QUrl, QUrl> resolveUrls(const QList<QUrl>& urls) const;
+    QHash<QUrl, QUrl> resolveUrls(const QList<QUrl>& urls, bool statLocalFiles = true) const;
 
     /**
      * Resolves local file URLs through nie:url.
@@ -299,7 +303,7 @@ private:
     bool updateNieUrlOnLocalFile(const QUrl& resource, const QUrl& nieUrl);
 
     ClassAndPropertyTree * classAndPropertyTree();
-    
+
     enum UriType {
         GraphUri,
         ResourceUri
