@@ -68,12 +68,12 @@ Nepomuk::ResourceMerger::~ResourceMerger()
 {
 }
 
-void Nepomuk::ResourceMerger::setMappings(const QHash< KUrl, KUrl >& mappings)
+void Nepomuk::ResourceMerger::setMappings(const QHash< QUrl, QUrl >& mappings)
 {
     m_mappings = mappings;
 }
 
-QHash< KUrl, KUrl > Nepomuk::ResourceMerger::mappings() const
+QHash< QUrl, QUrl > Nepomuk::ResourceMerger::mappings() const
 {
     return m_mappings;
 }
@@ -330,6 +330,8 @@ bool Nepomuk::ResourceMerger::checkGraphMetadata(const QMultiHash< QUrl, Soprano
     ClassAndPropertyTree* tree = m_model->classAndPropertyTree();
 
     QList<QUrl> types;
+    types << NRL::Graph();
+
     QHash<QUrl, int> propCardinality;
 
     QHash< QUrl, Soprano::Node >::const_iterator it = hash.constBegin();
@@ -463,7 +465,7 @@ Soprano::Node Nepomuk::ResourceMerger::resolveMappedNode(const Soprano::Node& no
 {
     // Find in mappings
     const QUrl uri = node.isBlank() ? node.toN3() : node.uri();
-    QHash< KUrl, KUrl >::const_iterator it = m_mappings.constFind( uri );
+    QHash< QUrl, QUrl >::const_iterator it = m_mappings.constFind( uri );
     if( it != m_mappings.constEnd() ) {
         return it.value();
     }
@@ -488,7 +490,7 @@ Soprano::Node Nepomuk::ResourceMerger::resolveUnmappedNode(const Soprano::Node&
     if( !node.isBlank() )
         return node;
 
-    QHash< KUrl, KUrl >::const_iterator it = m_mappings.constFind( QUrl(node.toN3()) );
+    QHash< QUrl, QUrl >::const_iterator it = m_mappings.constFind( QUrl(node.toN3()) );
     if( it != m_mappings.constEnd() ) {
         return it.value();
     }
@@ -496,7 +498,7 @@ Soprano::Node Nepomuk::ResourceMerger::resolveUnmappedNode(const Soprano::Node&
     QUrl newUri = createResourceUri();
     m_mappings.insert( QUrl(node.toN3()), newUri );
 
-    Soprano::Node dateTime( Soprano::LiteralValue( QDateTime::currentDateTime() ) );
+    Soprano::Node dateTime( ( Soprano::LiteralValue( QDateTime::currentDateTime() ) ) );
     m_model->addStatement( newUri, NAO::created(), dateTime, m_graph );
     m_model->addStatement( newUri, NAO::lastModified(), dateTime, m_graph );
 
@@ -729,13 +731,24 @@ bool Nepomuk::ResourceMerger::merge( const Soprano::Graph& stGraph )
                     continue;
                 }
 
-                // TODO: Maybe list the existing values as well?
+                //
+                // Display a very informative error message
+                //
+                QString query = QString::fromLatin1("select distinct ?v where {"
+                                                    " %1 %2 ?v ."
+                                                    "FILTER( %3 ) . }")
+                                    .arg( Soprano::Node::resourceToN3( subUri ),
+                                          Soprano::Node::resourceToN3( propUri ),
+                                          filterStringList.join( QLatin1String(" && ") ) );
+                QList< Soprano::Node > existingValues = m_model->executeQuery( query, Soprano::Query::QueryLanguageSparql ).iterateBindings(0).allNodes();
+
                 QString error = QString::fromLatin1("%1 has a max cardinality of %2. Provided "
-                                                    "%3 values - %4")
+                                                    "%3 values - %4. Existing - %5")
                                 .arg( propUri.toString(),
                                       QString::number(maxCardinality),
                                       QString::number(objectN3.size()),
-                                      objectN3.join(QLatin1String(", ")) );
+                                      objectN3.join(QLatin1String(", ")),
+                                      nodesToN3(existingValues).join(QLatin1String(", ")) );
                 setError( error, Soprano::Error::ErrorInvalidStatement );
                 return false;
             }
@@ -920,11 +933,22 @@ bool Nepomuk::ResourceMerger::merge( const Soprano::Graph& stGraph )
     // Handle Resource metadata
     //
 
+    QSet<QUrl> trailingGraphCandidates = m_graphHash.keys().toSet();
+
     // TODO: Maybe inform the RVM about these metadata changes?
     // First update the mtime of all the modified resources
     Soprano::Node currentDateTime = Soprano::LiteralValue( QDateTime::currentDateTime() );
     foreach( const QUrl & resUri, modifiedResources ) {
-        m_model->removeAllStatements( resUri, NAO::lastModified(), Soprano::Node() );
+        Soprano::QueryResultIterator it
+                = m_model->executeQuery(QString::fromLatin1("select distinct ?g where { graph ?g { %1 %2 ?o . } . }")
+                                        .arg(Soprano::Node::resourceToN3(resUri),
+                                             Soprano::Node::resourceToN3(NAO::lastModified())),
+                                        Soprano::Query::QueryLanguageSparql);
+        while(it.next()) {
+            const Soprano::Node g = it["g"];
+            m_model->removeAllStatements( resUri, NAO::lastModified(), Soprano::Node(), g );
+            trailingGraphCandidates << g.uri();
+        }
         m_model->addStatement( resUri, NAO::lastModified(), currentDateTime, m_graph );
     }
 
@@ -933,6 +957,8 @@ bool Nepomuk::ResourceMerger::merge( const Soprano::Graph& stGraph )
         addResMetadataStatement( st );
     }
 
+    m_model->removeTrailingGraphs(trailingGraphCandidates);
+
     return true;
 }
 
