@@ -69,10 +69,14 @@ private Q_SLOTS:
     void testRemoveProperty_file();
     void testRemoveProperty_invalid_args();
     void testRemoveProperty_protectedTypes();
+    void testRemoveProperty_subResource();
+    void testRemoveProperty_subResource2();
 
     void testRemoveProperties();
     void testRemoveProperties_invalid_args();
     void testRemoveProperties_protectedTypes();
+    void testRemoveProperties_subResource();
+    void testRemoveProperties_subResource2();
 
     void testRemoveResources();
     void testRemoveResources_subresources();
@@ -136,6 +140,7 @@ private Q_SLOTS:
     void testStoreResources_itemUris();
     void testStoreResources_kioProtocols();
     void testStoreResources_duplicates();
+    void testStoreResources_duplicates2();
     void testStoreResources_overwriteProperties();
     void testStoreResources_correctDomainInStore();
     void testStoreResources_correctDomainInStore2();
@@ -147,11 +152,16 @@ private Q_SLOTS:
     void testStoreResources_lazyCardinalities();
     void testStoreResources_graphMetadataFail();
     void testStoreResources_randomNepomukUri();
+    void testStoreResources_legacyData();
+    void testStoreResources_missingBlankNode();
+    void testStoreResources_graphChecks();
 
     void testMergeResources();
     void testMergeResources_protectedTypes();
 
     void testDescribeResources();
+    void testDescribeResources_relatedResources();
+    void testDescribeResources_excludeDiscardableData();
 
     void testImportResources();
 
@@ -160,6 +170,7 @@ private:
 
     void resetModel();
     bool haveTrailingGraphs() const;
+    bool haveDataInDefaultGraph() const;
 
     KTempDir* m_storageDir;
     Soprano::Model* m_model;
